@@ -7,7 +7,7 @@ from tinkoff.investments.model.user.accounts import UserAccount, UserAccounts
 class UserAPI(BaseTinkoffInvestmentsAPI):
     async def get_accounts(self) -> List[UserAccount]:
         payload = await self._request(
-            method='GET',
-            path='/user/accounts',
+            method="GET",
+            path="/user/accounts",
         )
         return UserAccounts.from_dict(payload).accounts
